---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Code snippet allowing reproducing the behaviour:
```python
# code here
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. iOS]
 - Version [e.g. 22]
- microscopy-portfolio version [e.g. 0.0.5]

**Environment:**
Please add here the content of your conda environment with versions.

**Additional context**
Add any other context about the problem here.
